@@ -19,7 +19,7 @@ class ETH(BTC):
     async def pay_to_many(self, *args: Any, **kwargs: Any) -> NoReturn:
         raise NotImplementedError("Pay to many not available in ETH directly")
 
-    async def _convert_amounts(self, data: dict) -> dict:
+    async def _convert_amounts(self, data: dict) -> dict:  # pragma: no cover
         if not hasattr(self, "_fetched_token") and isinstance(self.xpub, dict):
             contract = self.xpub.get("contract")
             if contract:
